//
//  ViewController.m
//  GridButtonColumn
//
//  Created by Torrey Betts on 11/12/14.
//  Copyright (c) 2014 Infragistics. All rights reserved.
//


#import <IG/IG.h>
#import "ViewController.h"

@interface ButtonCell : IGGridViewCell
{
    UIButton *_button;
}

- (void)buttonText:(NSString *)title;

@end

@implementation ButtonCell

- (instancetype)initWithReuseIdentifier:(NSString *)identifier
{
    self = [super initWithReuseIdentifier:identifier];
    if (self)
    {
        _button = [UIButton buttonWithType:UIButtonTypeRoundedRect];
        [_button addTarget:self action:@selector(tappedButton) forControlEvents:UIControlEventTouchUpInside];
        [self addSubview:_button];
    }

    return self;
}

- (void)setupSize:(CGSize)size
{
    _button.frame = CGRectMake(0, 0, size.width, size.height);
}

- (void)tappedButton
{
    [_button setTitle:@"Pressed" forState:UIControlStateNormal];
}

- (void)buttonText:(NSString *)title
{
    [_button setTitle:title forState:UIControlStateNormal];
}

@end

@interface ButtonColumn : IGGridViewColumnDefinition
@end

@implementation ButtonColumn

- (NSString *)fieldKey
{
    return @"BC";
}

- (IGGridViewCell *)gridView:(IGGridView *)gridView createCell:(IGCellPath *)path usingDataSource:(IGGridViewDataSourceHelper *)dataSource
{
    ButtonCell *cell = (ButtonCell *) [gridView dequeueReusableCellWithIdentifier:@"BC"];
    if (!cell)
    {
        cell = [[ButtonCell alloc] initWithReuseIdentifier:@"BC"];
    }

    [cell buttonText:@"Push"];
    return cell;
}


@end

@interface ViewController ()
{
    IGGridView *_gridView;
    IGGridViewDataSourceHelper *_helper;
    NSArray *_data;
}
@end

@implementation ViewController


- (void)viewDidLoad
{
    [super viewDidLoad];

    _gridView = [[IGGridView alloc] initWithFrame:self.view.bounds style:IGGridViewStyleDefault];
    _gridView.autoresizingMask = UIViewAutoresizingFlexibleHeight|UIViewAutoresizingFlexibleWidth;
    _gridView.headerHeight = 0;
    [self.view addSubview:_gridView];

    _data = @[@"Row 1", @"Row 2", @"Row 3", @"Row 4", @"Row 5"];
    _helper = [[IGGridViewDataSourceHelper alloc] init];

    ButtonColumn *buttonColumn = [[ButtonColumn alloc] initWithKey:@"BC"];
    [_helper.columnDefinitions addObject:buttonColumn];
    _helper.data = _data;

    _gridView.dataSource = _helper;
}

@end